#include "GD754X_800x600x2x60hz.h"


static const SVGAIndexValuePair
CirrusLogicGD754X_800x600x2x60hz_generalRegisters[] = {
	{0, 0x3f},	// p.147: vert.sync=low,horz.sync=low,only even,enab.disp,mono
    {-1, 0}
};


static const SVGAIndexValuePair 
CirrusLogicGD754X_800x600x2x60hz_sequencerRegisters[] = {
    {0x00,0x03}, // p.167: SR0=Synchronous Reset|Asynchronous Reset
	{0x01,0x01}, // p.168: SR1=...|8 Dot Clock (for 640 horiz-pixel).
	{0x02,0x0F}, // p.170: SR2=enable writing to the four bitmap planes.
	{0x03,0x00}, // p.171: SR3=1st & 2nd character map select={0,0}
	{0x04,0x06}, // p.173: SR4=Odd/Even Mode=^GR5[4]|effective mem=actual mem.
				 //        SR4[2] must be opposite of GR5[4].
	{0x06,0x12}, // p.235: unlock extension registers.
	{0x07,0x00}, // p.236: Ext.Seq.Mode Reg. std VGA disp.mem. 8b/pix. 1xVCLK
    {-1, 0}
};


static const SVGAIndexValuePair
CirrusLogicGD754X_800x600x2x60hz_crtControllerRegisters[] = {
    {0x11,0x00}, // p.197: Vert.Sync.End     (Turn off lock>allow chang 0..7)
    {0x00,0x7b}, // p.176: Horiz.Total       1024=(123+5)*8(SR[1,0])=1024
	{0x01,0x63}, // p.179: Horiz.Disp.End     800=(99+1)*8
	{0x02,0x64}, // p.180: Horiz.Blank.Start  801=(100+1)*8 >CR1.
	{0x03,0x84}, // p.181: Horiz.Blank.End     24=(4)*8     <64*8
	{0x04,0x69}, // p.183: Horiz.Sync.Start   960=(120)*8   <CR0-4*8
    {0x05,0x84}, // p.184: Horiz.Sync.End      32=(4)*8  CR3++|NoHoriSyncDlay
	{0x06,0x6f}, // p.186: Vertical Total    0x26f+2=625 (see CR7[5,0])
	{0x07,0xf0}, // p.187: Overflow Reg.
	{0x08,0x00}, // p.188: Screen A Preset Row Scan
	{0x09,0x60}, // p.189: Char.Cell.Height. 16-1?
    {0x0A,0x00}, // p.190: Text.Curs.Start   enable cursor, line cursor.
	{0x0B,0x00}, // p.191: Text.Curs.End     no text cursor display.
	{0x0C,0x00}, // p.192: Screen A Start Addr High (see CR1B)
	{0x0D,0x00}, // p.193: Screen A Start Addr Low  0x00000
	{0x0E,0x02}, // p.194: Txt.Curs.Loc.High
    {0x0F,0xc8}, // p.195: Txt.Curs.Loc.Low  0x0000
	{0x10,0x58}, // p.196: Vert.Sync.Start.  0x258=600 (see CR7[7,2])
	{0x11,0x8a}, // p.197: Vert.Sync.End     lock CR0-CR7|vse=10 < 625-600
	{0x12,0x57}, // p.199: Vert.Disp.End     0x257=599 (see CR7[6,1])
	{0x13,0x32}, // p.200: Offset.Reg        50 =rowBytes?  (CR1B[4]; CR17)
    {0x14,0x00}, // p.201: Underl.Row.Scanl. underline start at 0.
	{0x15,0x58}, // p.202: Vert.Blank.Start  0x258=600 (see CR9[6],CR7[3])
	{0x16,0x19}, // p.203: Vert.Blank.End    0x19=25=625-600 (see CR1B)
	{0x17,0xe3}, // p.204: Mode Ctrl.        timing enab|byte-addr|noHERC|noCGA
	{0x18,0xff}, // p.206: Line Cmp (Scr.Split) 0x3FF=1024-1.
	{0x19,0xff}, // p.333: Interlace End
	{0x1a,0x00}, // p.334: VBEnd Ext,HBEnd Ext,DACModeSwitch,DispStart,Intrlc.
    {0x1b,0x02}, // p.336: Misc.             Extended Address Wrap Enable
				 // 0x01?
				 // 0x1d,0x22 seems not to be relevant to 754X
    {-1, 0}
};


static const SVGAIndexValuePair
CirrusLogicGD754X_800x600x2x60hz_graphicsControllerRegisters[] = {
    {0x00,0x00}, // p.212: Set/Reset Reg.    background color.
	{0x01,0x00}, // p.213: Set/Reset Enable  foreground color.
	{0x02,0x00}, // p.214: Color Cmp Reg.    disabled by GR5[3]=0
	{0x03,0x00}, // p.215: Data Rotate Reg.  
	{0x04,0x00}, // p.216: Read Map Plane Sel. Disp. Mem. Data Plane 0
    {0x05,0x00}, // p.217: Mode Reg.         16-,4-,2- color graphic mode|
	             //  EGA compat. |=^SR4[2]|bypass GR3(CPU directly reads vram)|
				 //  Write mode 0.
				 //        SR4[2] must be opposite of GR5[4].
	{0x06,0x05}, // p.220: Misc.Reg.         EGA/VGA A000:0-AFFF:F 64KB|graphic
			// was 0x05
	{0x07,0x0F}, // p.222: Color Don't-Care Plane    all planes involved.
	{0x08,0xFF}, // p.223: Disp.Mem.Bit.Mask. Write all bits.
	{0x09,0x00}, // p.298: Offset Register 0
	{0x0a,0x00}, // p.300: Offset Register 1
	{0x0b,0x00}, // p.301: Mode Ext. Register 0=1MB-linear-addressing
    {-1, 0}
};


static const SVGAIndexValuePair
CirrusLogicGD754X_800x600x2x60hz_attributeControllerRegisters[] = {
	{0x00,0x00}, // p.226: Attr.Cntrler.Palette Reg. 0
	{0x01,0x01}, // p.226: Attr.Cntrler.Palette Reg. 1
	{0x02,0x02}, // p.226: Attr.Cntrler.Palette Reg. 2
	{0x03,0x03}, // p.226: Attr.Cntrler.Palette Reg. 3
	{0x04,0x04}, // p.226: Attr.Cntrler.Palette Reg. 4
	{0x05,0x05}, // p.226: Attr.Cntrler.Palette Reg. 5
	{0x06,0x06}, // p.226: Attr.Cntrler.Palette Reg. 6
	{0x07,0x07}, // p.226: Attr.Cntrler.Palette Reg. 7
	{0x08,0x08}, // p.226: Attr.Cntrler.Palette Reg. 8
	{0x09,0x09}, // p.226: Attr.Cntrler.Palette Reg. 9
	{0x0A,0x0A}, // p.226: Attr.Cntrler.Palette Reg. a
	{0x0B,0x0B}, // p.226: Attr.Cntrler.Palette Reg. b
	{0x0C,0x0C}, // p.226: Attr.Cntrler.Palette Reg. c
	{0x0D,0x0D}, // p.226: Attr.Cntrler.Palette Reg. d
	{0x0E,0x0E}, // p.226: Attr.Cntrler.Palette Reg. e
	{0x0F,0x0F}, // p.226: Attr.Cntrler.Palette Reg. f
	{0x10,0x01}, // p.227: Attr.Cntrler.Mode Reg. ...|disable char blink|...|
	             //   attrib=back.color|graphic mode.
	{0x11,0x00}, // p.229: OverScan(border)Color Reg. CLUT entry 0 (=black).
	{0x12,0x0F}, // p.230: Color Plane Enable Reg.  enable all planes.
	{0x13,0x00}, // p.232: Pixel Paning
	{0x14,0x00}, // p.233: Color Select Reg.        ignored.
	{-1, 0}
};


const CirrusLogicGD754XMode CirrusLogicGD754X_800x600x2x60hz = {
    "800x600x2x60hz",
    CirrusLogicGD754X_800x600x2x60hz_generalRegisters,
    CirrusLogicGD754X_800x600x2x60hz_sequencerRegisters,
    CirrusLogicGD754X_800x600x2x60hz_crtControllerRegisters,
    CirrusLogicGD754X_800x600x2x60hz_graphicsControllerRegisters,
    CirrusLogicGD754X_800x600x2x60hz_attributeControllerRegisters,
};


/* END GD754X_800x600x2x60hz */
